@@ -45,17 +45,17 @@ public:
     {
         if (!kget) {
 #ifdef DEBUG
-            kget = new MainWindow(!parser->isSet("showDropTarget"), parser->isSet("startWithoutAnimation"), parser->isSet("test"));
+            kget = new MainWindow(!parser->isSet("hideMainWindow"), parser->isSet("startWithoutAnimation"), parser->isSet("test"));
 #else
-            kget = new MainWindow(!parser->isSet("showDropTarget"), parser->isSet("startWithoutAnimation"), false);
+            kget = new MainWindow(!parser->isSet("hideMainWindow"), parser->isSet("startWithoutAnimation"), false);
 #endif
 
             auto *wrapper = new DBusKGetWrapper(kget);
             new MainAdaptor(wrapper);
             QDBusConnection::sessionBus().registerObject("/KGet", wrapper);
-        } else {
+        } else if (!parser->isSet("hideMainWindow")) {
             // activate window if it is already open
-            kget->setAttribute(Qt::WA_NativeWindow, true);
+            kget->show();
             KWindowSystem::updateStartupId(kget->windowHandle());
             KWindowSystem::activateWindow(kget->windowHandle());
         }
